# Changelog

## v0.1.4 - 20230-05-12
### Added
- support proxy host for notion


## v0.1.3 - 20230-04-09
### Added
- support old version python like python3.8

## v0.1.2 - 2023-03-13

### Fixed
- fix bug when get space id using `get_spaces` api

## v0.1.1 - 2023-03-07

### Improved
- add new api `get_spaces` to auto get space id

## v0.1.0 - 2023-02-23

### Fixed
- Fixed response none when Notion start to charge for the API
